# SearchSource: Enter SearchSource

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): search updates, get_masterdata, run_search, load_fixes, prep

[TRID](https://trid.trb.org/)

## Add the search source

```
colrev search -a XXX
```

## Links
